@@ -21,10 +21,10 @@ import six
 from horizon import exceptions
 from horizon import forms
 from horizon import workflows
-from openstack_dashboard.api import network
+from openstack_dashboard.api import neutron
 
 from sahara_dashboard.api import sahara as saharaclient
-
+from sahara_dashboard import utils
 
 LOG = logging.getLogger(__name__)
 
@@ -190,7 +190,7 @@ def get_security_groups(request, security_group_ids):
     security_groups = []
     for group in security_group_ids or []:
         try:
-            security_groups.append(network.security_group_get(
+            security_groups.append(neutron.security_group_get(
                 request, group))
         except Exception:
             LOG.info(_('Unable to retrieve security group %(group)s.') %
@@ -261,9 +261,12 @@ class PluginAndVersionMixin(object):
                        'data-slug': 'pluginname'}))
 
         for plugin in plugins:
-            version_choices = (sorted(
-                [(version, version)
-                 for version in get_enabled_versions(plugin)], reverse=True))
+            versions = [(version, version)
+                        for version in get_enabled_versions(plugin)]
+            version_choices = sorted(
+                versions,
+                reverse=True,
+                key=lambda v: utils.smart_sort_helper(v[0]))
             field_name = plugin.name + "_version"
             choice_field = forms.ChoiceField(
                 label=_("Version"),
@@ -437,7 +440,7 @@ def get_enabled_versions(plugin):
     lbs = plugin.version_labels
 
     versions = []
-    for version, data in six.iteritems(lbs):
+    for version, data in lbs.items():
         if data.get('enabled', {'status': True}).get('status', True):
             versions.append(version)
 
@@ -449,7 +452,7 @@ def get_enabled_versions(plugin):
 
 def is_version_of_plugin_deprecated(plugin, version):
     lbs = plugin.version_labels
-    for iter_version, data in six.iteritems(lbs):
+    for iter_version, data in lbs.items():
         if iter_version == version:
             if data.get('deprecated', {'status': False}).get('status', False):
                 return True
